@@ -147,7 +147,12 @@ class SFAddMenu(BrowserView):
             portal_types = portal_type
         elif portal_type:
             portal_types = [portal_type,]
-        if not self.portal.restrictedTraverse(copyDict['url']).portal_type in portal_types:
+        item = None
+        try:
+            item = self.portal.restrictedTraverse(copyDict['url'])
+        except:
+            pass
+        if item and not item.portal_type in portal_types:
             return []
         results = []
 
@@ -428,3 +433,8 @@ class SolgemaFullcalendarResizeView(BrowserView):
         obj.reindexObject()
         return True
 
+class SolgemaFullcalendarActionGuards(BrowserView):
+
+    def is_calendar_layout(self):
+        selected_layout = getattr(self.context, 'layout', '')
+        return selected_layout == 'solgemafullcalendar_view'
