@@ -306,6 +306,9 @@ class SolgemaFullcalendarJS(BrowserView):
         else:
             return '/'+self.context.absolute_url(relative=1)
 
+    def getTopicAbsoluteUrl(self):
+        return self.context.absolute_url()
+
     def __call__(self):
         self.request.RESPONSE.setHeader('Content-Type','application/x-javascript; charset=utf-8')
         return super(SolgemaFullcalendarJS, self).__call__()
