@@ -11,6 +11,14 @@ def updateRegistries(context):
     csstool = getToolByName(context, 'portal_css')
     csstool.cookResources()
 
+def checkPortalTypes(context):
+    #be sure solgemafullcalendar_view is installed
+    ttool = getToolByName(context, 'portal_types')
+    topic_type = ttool.Topic
+    topic_methods = topic_type.view_methods
+    if 'solgemafullcalendar_view' not in topic_methods:
+        topic_type.manage_changeProperties(view_methods=topic_methods+tuple(['solgemafullcalendar_view',]))
+
 def upgrade03(context):
     portal_quickinstaller = getToolByName(context, 'portal_quickinstaller')
     portal_setup = getToolByName(context, 'portal_setup')
@@ -62,3 +70,17 @@ def upgrade16(context):
         topic_type.manage_changeProperties(view_methods=topic_methods+tuple(['solgemafullcalendar_view',]))
     updateRegistries(context)
 
+def upgrade17(context):
+
+    portal_quickinstaller = getToolByName(context, 'portal_quickinstaller')
+    portal_setup = getToolByName(context, 'portal_setup')
+
+    for product in PRODUCT_DEPENDENCIES:
+        if not portal_quickinstaller.isProductInstalled(product):
+            portal_quickinstaller.installProduct(product)
+            transaction.savepoint()
+
+    portal_setup.runAllImportStepsFromProfile('profile-Solgema.fullcalendar:upgrade17', purge_old=False)
+    checkPortalTypes(context)
+    updateRegistries(context)
+
