@@ -334,7 +334,7 @@ function readCookie(name) {
       startParam: "start:int",
       endParam: "end:int",
       ignoreTimezone: false,
-      events: "solgemafullcalendarevents",
+      events: SolgemaFullcalendarVars.topicAbsoluteUrl + "/solgemafullcalendarevents",
       axisFormat: SolgemaFullcalendarVars.axisFormat,
       allDaySlot: SolgemaFullcalendarVars.allDaySlot,
       allDayText: SolgemaFullcalendarVars.allDayText,
