@@ -46,10 +46,10 @@ def availableCriterias( topic ):
     portal_atct = getToolByName(topic, 'portal_atct')
     for criteria in topic.listCriteria():
         field = criteria.Field()
-        if criteria.meta_type=='ATPortalTypeCriterion' and len(criteria.getCriteriaItems()[0][1])>1:
+        if criteria.meta_type=='ATPortalTypeCriterion' and len(criteria.getCriteriaItems()[0][1])>0:
             index = portal_atct.getIndex(field).friendlyName or ortal_atct.getIndex(field).index
             li.append({'id':field, 'title':topic.translate(index)})
-        elif criteria.meta_type in ['ATSelectionCriterion', 'ATListCriterion'] and len(criteria.getCriteriaItems()[0][1]['query'])>1:
+        elif criteria.meta_type in ['ATSelectionCriterion', 'ATListCriterion'] and criteria.getCriteriaItems() and len(criteria.getCriteriaItems()[0])>1 and len(criteria.getCriteriaItems()[0][1]['query'])>0:
             index = portal_atct.getIndex(field).friendlyName or ortal_atct.getIndex(field).index
             li.append({'id':field, 'title':topic.translate(index)})
     return TitledVocabulary.fromTitles([(crit['id'], crit['title']) for crit in li])
